@@ -27,7 +27,7 @@
 class MoveTest : public QObject
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
     void initTestCase();
 
     void x1() const;
